emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] 09/299: * style/lscape.el: New style by Mads Jensen <address@hidd


From: Stefan Monnier
Subject: [elpa] 09/299: * style/lscape.el: New style by Mads Jensen <address@hidden>. * style/amssymb.el: Ditto.
Date: Sun, 02 Nov 2014 03:09:50 +0000

monnier pushed a commit to branch externals/auctex
in repository elpa.

commit b9ed958e20981eecc932317d762e1e7476e95e7c
Author: Tassilo Horn <address@hidden>
Date:   Wed Dec 26 18:58:11 2012 +0000

    * style/lscape.el: New style by Mads Jensen <address@hidden>.
    * style/amssymb.el: Ditto.
---
 ChangeLog                      |    6 +-
 style/amssymb.el               |  248 ++++++++++++++++++++++++++++++++++++++++
 style/bigstrut.el              |    6 +-
 style/{xspace.el => lscape.el} |   35 +++----
 style/xspace.el                |    1 +
 5 files changed, 271 insertions(+), 25 deletions(-)

diff --git a/ChangeLog b/ChangeLog
index 873978f..a26115e 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,6 +1,10 @@
 2012-12-26  Tassilo Horn  <address@hidden>
 
-       * style/ragged2e.el: New style by Mads Jensen <address@hidden>.
+       * style/lscape.el: New style by Mads Jensen <address@hidden>.
+
+       * style/amssymb.el: Ditto.
+
+       * style/ragged2e.el: Ditto.
 
        * style/mathtools.el: Ditto.
 
diff --git a/style/amssymb.el b/style/amssymb.el
new file mode 100644
index 0000000..78ebd63
--- /dev/null
+++ b/style/amssymb.el
@@ -0,0 +1,248 @@
+;;; amssymb.el --- AUCTeX style for `amssymb.sty'
+
+;; Copyright (C) 2012 Free Software Foundation, Inc.
+
+;; Author: Mads Jensen <address@hidden>
+;; Maintainer: address@hidden
+;; Keywords: tex
+
+;; This file is part of AUCTeX.
+
+;; AUCTeX is free software; you can redistribute it and/or modify it
+;; under the terms of the GNU General Public License as published by
+;; the Free Software Foundation; either version 3, or (at your option)
+;; any later version.
+
+;; AUCTeX is distributed in the hope that it will be useful, but
+;; WITHOUT ANY WARRANTY; without even the implied warranty of
+;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+;; General Public License for more details.
+
+;; You should have received a copy of the GNU General Public License
+;; along with AUCTeX; see the file COPYING.  If not, write to the Free
+;; Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+;; 02110-1301, USA.
+
+;;; Commentary:
+
+;; This file adds support for `amssymb.sty'.
+
+;; The commands were just taken out of the \DeclareMathSymbol from
+;; amssymb.sty in the order specified there, i.e., \mathord, \mathbin,
+;; \mathrel
+
+;;; Code:
+
+(TeX-add-style-hook
+ "amssymb"
+ (lambda ()
+   (TeX-add-symbols
+    "boxdot"
+    "boxplus"
+    "boxtimes"
+    "square"
+    "blacksquare"
+    "centerdot"
+    "lozenge"
+    "blacklozenge"
+    "circlearrowright"
+    "circlearrowleft"
+    "leftrightharpoons"
+    "boxminus"
+    "Vdash"
+    "Vvdash"
+    "vDash"
+    "twoheadrightarrow"
+    "twoheadleftarrow"
+    "leftleftarrows"
+    "rightrightarrows"
+    "upuparrows"
+    "downdownarrows"
+    "upharpoonright"
+    "downharpoonright"
+    "upharpoonleft"
+    "downharpoonleft"
+    "rightarrowtail"
+    "leftarrowtail"
+    "leftrightarrows"
+    "rightleftarrows"
+    "Lsh"
+    "Rsh"
+    "rightsquigarrow"
+    "leftrightsquigarrow"
+    "looparrowleft"
+    "looparrowright"
+    "circeq"
+    "succsim"
+    "gtrsim"
+    "gtrapprox"
+    "multimap"
+    "therefore"
+    "because"
+    "doteqdot"
+    "triangleq"
+    "precsim"
+    "lesssim"
+    "lessapprox"
+    "eqslantless"
+    "eqslantgtr"
+    "curlyeqprec"
+    "curlyeqsucc"
+    "preccurlyeq"
+    "leqq"
+    "leqslant"
+    "lessgtr"
+    "backprime"
+    "risingdotseq"
+    "fallingdotseq"
+    "succcurlyeq"
+    "geqq"
+    "geqslant"
+    "gtrless"
+    "vartriangleright"
+    "vartriangleleft"
+    "trianglerighteq"
+    "trianglelefteq"
+    "bigstar"
+    "between"
+    "blacktriangledown"
+    "blacktriangleright"
+    "blacktriangleleft"
+    "vartriangle"
+    "blacktriangle"
+    "triangledown"
+    "eqcirc"
+    "lesseqgtr"
+    "gtreqless"
+    "lesseqqgtr"
+    "gtreqqless"
+    "Rrightarrow"
+    "Lleftarrow"
+    "veebar"
+    "barwedge"
+    "doublebarwedge"
+    "measuredangle"
+    "sphericalangle"
+    "varpropto"
+    "smallsmile"
+    "smallfrown"
+    "Subset"
+    "Supset"
+    "Cup"
+    "Cap"
+    "curlywedge"
+    "curlyvee"
+    "leftthreetimes"
+    "rightthreetimes"
+    "subseteqq"
+    "supseteqq"
+    "bumpeq"
+    "Bumpeq"
+    "lll"
+    "ggg"
+    "circledS"
+    "pitchfork"
+    "dotplus"
+    "backsim"
+    "backsimeq"
+    "complement"
+    "intercal"
+    "circledcirc"
+    "circledast"
+    "circleddash"
+    "lvertneqq"
+    "gvertneqq"
+    "nleq"
+    "ngeq"
+    "nless"
+    "ngtr"
+    "nprec"
+    "nsucc"
+    "lneqq"
+    "gneqq"
+    "nleqslant"
+    "ngeqslant"
+    "lneq"
+    "gneq"
+    "npreceq"
+    "nsucceq"
+    "precnsim"
+    "succnsim"
+    "lnsim"
+    "gnsim"
+    "nleqq"
+    "ngeqq"
+    "precneqq"
+    "succneqq"
+    "precnapprox"
+    "succnapprox"
+    "lnapprox"
+    "gnapprox"
+    "nsim"
+    "ncong"
+    "diagup"
+    "diagdown"
+    "varsubsetneq"
+    "varsupsetneq"
+    "nsubseteqq"
+    "nsupseteqq"
+    "subsetneqq"
+    "supsetneqq"
+    "varsubsetneqq"
+    "varsupsetneqq"
+    "subsetneq"
+    "supsetneq"
+    "nsubseteq"
+    "nsupseteq"
+    "nparallel"
+    "nmid"
+    "nshortmid"
+    "nshortparallel"
+    "nvdash"
+    "nVdash"
+    "nvDash"
+    "nVDash"
+    "ntrianglerighteq"
+    "ntrianglelefteq"
+    "ntriangleleft"
+    "ntriangleright"
+    "nleftarrow"
+    "nrightarrow"
+    "nLeftarrow"
+    "nRightarrow"
+    "nLeftrightarrow"
+    "nleftrightarrow"
+    "divideontimes"
+    "varnothing"
+    "nexists"
+    "Finv"
+    "Game"
+    "eth"
+    "eqsim"
+    "beth"
+    "gimel"
+    "daleth"
+    "lessdot"
+    "gtrdot"
+    "ltimes"
+    "rtimes"
+    "shortmid"
+    "shortparallel"
+    "smallsetminus"
+    "thicksim"
+    "thickapprox"
+    "approxeq"
+    "succapprox"
+    "precapprox"
+    "curvearrowleft"
+    "curvearrowright"
+    "digamma"
+    "varkappa"
+    "Bbbk"
+    "hslash"
+    "backepsilon")))
+
+(defvar LaTeX-amssymb-package-options '("psamsfonts")
+  "Package options for the amssymb package.")
+
+;;; amssymb.el ends here.
diff --git a/style/bigstrut.el b/style/bigstrut.el
index 9019085..0c9953e 100644
--- a/style/bigstrut.el
+++ b/style/bigstrut.el
@@ -32,14 +32,14 @@
 (TeX-add-style-hook
  "bigstrut"
  (lambda ()
-   (TeX-add-symbols 
+   (TeX-add-symbols
     "bigstrutsetup"
     '("bigstrut" [ TeX-arg-bigstrut ]))))
 
 (defun TeX-arg-bigstrut (optional &optional prompt)
   "Prompt for the optional argument in \\bigstrut"
-  (TeX-argument-insert 
-   (completing-read (TeX-argument-prompt 
+  (TeX-argument-insert
+   (completing-read (TeX-argument-prompt
      optional "Strut to top (t) or bottom (b)" nil t)
      (mapcar 'list '("t" "b")) nil t) optional))
 
diff --git a/style/xspace.el b/style/xspace.el
index 15f9216..c94a653 100644
--- a/style/xspace.el
+++ b/style/xspace.el
@@ -3,6 +3,7 @@
 ;; Copyright (C) 2011 Free Software Foundation, Inc.
 
 ;; Author: Mads Jensen <address@hidden>
+;; Maintainer: address@hidden
 ;; Created: 2011-02-01
 ;; Keywords: tex
 



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/style/xspace.el b/style/lscape.el
similarity index 61%
copy from style/xspace.el
copy to style/lscape.el
index 15f9216..dcacd9c 100644
--- a/style/xspace.el
+++ b/style/lscape.el
@@ -1,9 +1,10 @@
 ;;; xspace.el --- AUCTeX style for `xspace.sty'
 
 ;; Copyright (C) 2011 Free Software Foundation, Inc.
 
 ;; Author: Mads Jensen <address@hidden>
-;; Created: 2011-02-01
+;; Maintainer: address@hidden
+;; Created: 2011-05-04
 ;; Keywords: tex
 
 ;; This file is part of AUCTeX.
@@ -25,27 +26,19 @@
 
 ;;; Commentary:
 
 ;; This file adds support for `xspace.sty'.
 
 ;;; Code:
 
 (TeX-add-style-hook
- "xspace"
+ "lscape"
  (lambda ()
-   (TeX-add-symbols
-    '("xspace" 0)
-    "xspaceaddexception"
-    "xspaceremoveexception")
-
-   ;; Fontification
-   (when (and (featurep 'font-latex)
-             (eq TeX-install-font-lock 'font-latex-setup))
-     (font-latex-add-keywords '(("xspace" "")
-                               ("xspaceaddexception" "{")
-                               ("xspaceremoveexception" "{"))
-                             'function))))
-
-(defvar LaTeX-xspace-package-options nil
-  "Package options for the xspace package.")
-
-;;; xspace.el ends here
+   (LaTeX-add-environments
+    "landscapee"))
+ ;; lscape uses graphics internally to handle the work
+ (TeX-run-style-hooks "graphics"))
+
+(defvar LaTeX-lscape-package-options '("pdftex")
+  "Package options for the lscape package.")
+
+;;; lscape.el ends here
@@ -1,9 +1,10 @@
-;;; xspace.el --- AUCTeX style for `xspace.sty'
+;;; lscape.el --- AUCTeX style for `lscape.sty'
 
 ;; Copyright (C) 2011 Free Software Foundation, Inc.
@@ -25,27 +26,19 @@
 ;;; Commentary:
 
-;; This file adds support for `xspace.sty'.
+;; This file adds support for `lscape.sty'.
 
 ;;; Code: